..
   Copyright (C) 2024 Roberto Rossini <roberros@uio.no>
   SPDX-License-Identifier: MIT

Cooler API
##########

.. py:module:: hictkpy.cooler
.. py:currentmodule:: hictkpy.cooler

.. autoclass:: SingleCellFile
   :members:
   :special-members: __init__

.. autoclass:: FileWriter
   :members:
   :special-members: __init__
